@@ -8,8 +8,9 @@ package Text::Layout::FontDescriptor;
 
 use Carp;
 
+use Text::Layout::Version;
 
-our $VERSION = "0.013";
+our $VERSION = $Text::Layout::VERSION;
 
 =head1 NAME
 
@@ -103,7 +104,9 @@ sub get_font {
 
 =item get_weight
 
-Accessors to the font family, style. and weight.
+=item get_shaping
+
+Accessors to the font family, style, weight and shaping.
 
 Readonly.
 
@@ -131,6 +134,11 @@ sub get_size {
     $self->{size};
 }
 
+sub get_shaping {
+    my ( $self ) = @_;
+    $self->{shaping};
+}
+
 =over
 
 =item set_size
@@ -150,6 +158,21 @@ sub set_size {
 
 =over
 
+=item set_shaping
+
+Sets/gets the shaping property of the font.
+
+=back
+
+=cut
+
+sub set_shaping {
+    my ( $self, $sh ) = @_;
+    $self->{shaping} = $sh // 1;
+}
+
+=over
+
 =item to_string
 
 Returns a Pango-style font string, C<Sans Italic 14>.
