@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
+use lib "../CPAN";
 use PDF::API2;
 
 use lib "../lib";
@@ -26,7 +27,7 @@ my $PANGO_SCALE;
 
 sub main {
     # Select a font.
-    my $font = Text::Layout::FontConfig->from_string("Sanss 60");
+    my $font = Text::Layout::FontConfig->from_string("Serif 60");
     $layout->set_font_description($font);
 
     # Start...
@@ -82,7 +83,8 @@ sub main {
     $y -= 100;
 
     # This will only work properly with the HarfBuzz driver.
-    $font = Text::Layout::FontConfig->from_string("Deva 60");
+    $font = Text::Layout::FontConfig->from_filename("/usr/share/fonts/lohit-devanagari/Lohit-Devanagari.ttf");
+    $font->set_shaping;
     $layout->set_font_description($font);
     $layout->set_width( 595 * $PANGO_SCALE );
     $layout->set_alignment("right");
@@ -185,14 +187,6 @@ sub setup_fonts {
     $fd->register_font( "DejaVuSans-Oblique.ttf",     "Sans", "Italic"     );
     $fd->register_font( "DejaVuSans-BoldOblique.ttf", "Sans", "BoldItalic" );
 
-    # Add Devanagari. Requires shaping.
-    $fd->register_font( "lohit-devanagari/Lohit-Devanagari.ttf",
-			"Deva", "", "", { shaping => 1 } );
-
-    my $o = { interline => 1 };
-    $fd->register_font( "Helvetica", "Sanss", "", "", $o );
-    $fd->register_font( "HelveticaOblique", "Sanss", "Italic", "", $o );
-    $fd->register_font( "HelveticaBold", "Sanss", "Bold", "", $o );
 }
 
 ################ Main entry point ################
